pub enum DisassembleOptions {
    None,
    Print,
    Color,
    Indent,
    ShowByteOffset,
    NoHeader,
    FriendlyNames,
    Comment,
}

Variants

None

Print

Print to stdout

Color

Add color codes to output

Indent

Indent assembly

ShowByteOffset

NoHeader

Do not output the module header as leading comments in the assembly.

FriendlyNames

Use friendly names where possible. The heuristic may expand over time, but will use common names for scalar types, and debug names from OpName instructions.

Comment

Add some comments to the generated assembly